import { hasPermission, requestPermission } from "nativescript-permissions";
import { android as androidApp } from "@nativescript/core/application";
var Intent = android.content.Intent;
var PendingIntent = android.app.PendingIntent;
var GoogleApiAvailability = com.google.android.gms.common.GoogleApiAvailability;
var OnSuccessListener = com.google.android.gms.tasks.OnSuccessListener;
var OnFailureListener = com.google.android.gms.tasks.OnFailureListener;
export class AndroidAbstractRecognizerManager {
    constructor(receiver) {
        this.receiver = receiver;
    }
    isReady() {
        if (!isGooglePlayServicesAvailable()) {
            return false;
        }
        if (android.os.Build.VERSION.SDK_INT < 29) {
            return true;
        }
        return hasPermission(android.Manifest.permission.ACTIVITY_RECOGNITION);
    }
    async prepare() {
        if (!isGooglePlayServicesAvailable()) {
            await promisify(GoogleApiAvailability.getInstance().makeGooglePlayServicesAvailable(androidApp.foregroundActivity));
        }
        if (android.os.Build.VERSION.SDK_INT < 29) {
            return;
        }
        if (!hasPermission(android.Manifest.permission.ACTIVITY_RECOGNITION)) {
            await requestPermission(android.Manifest.permission.ACTIVITY_RECOGNITION);
        }
    }
    async startListening(options = {}) {
        if (this.isUp()) {
            await this.stopListening();
        }
        if (!this.isReady()) {
            throw new Error("Manager is not ready!. Call isReady() before start listening.");
        }
        const task = this.handleStart(androidApp.context, this.getPendingIntent(), options);
        await promisify(task);
    }
    async stopListening() {
        if (!this.isUp()) {
            return;
        }
        const pendingIntent = this.getPendingIntent();
        const task = this.handleStop(androidApp.context, pendingIntent);
        pendingIntent.cancel();
        this.pendingIntent = null;
        await promisify(task);
    }
    isUp() {
        const pendingIntent = PendingIntent.getBroadcast(androidApp.context, 0, this.getReceiverIntent(), PendingIntent.FLAG_NO_CREATE);
        return pendingIntent !== null;
    }
    getPendingIntent() {
        if (!this.pendingIntent) {
            const receiverIntent = this.getReceiverIntent();
            this.pendingIntent = PendingIntent.getBroadcast(androidApp.context, 0, receiverIntent, 0);
        }
        return this.pendingIntent;
    }
    getReceiverIntent() {
        return new Intent(androidApp.context, this.receiver);
    }
}
const CONNECTION_RESULT_SUCCESS = 0;
function isGooglePlayServicesAvailable() {
    return (GoogleApiAvailability.getInstance().isGooglePlayServicesAvailable(androidApp.context) === CONNECTION_RESULT_SUCCESS);
}
function promisify(task) {
    return new Promise((resolve, reject) => {
        task.addOnSuccessListener(getOnSuccessListener(resolve));
        task.addOnFailureListener(getOnFailureListener(reject));
    });
}
function getOnSuccessListener(onSuccess) {
    return new OnSuccessListener({
        onSuccess,
    });
}
function getOnFailureListener(onFailure) {
    return new OnFailureListener({
        onFailure(ex) {
            onFailure(new Error(ex.getMessage()));
        },
    });
}
//# sourceMappingURL=abstract-manager.android.js.map